==> cx88-1.3.0.tar.gz: cx88-1.3.0/client/drivers/cx88_cards.h <==
/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_CARDS_H__
#define __CX88_CARDS_H__

#include "tuner_config.h"

enum cx88_card_id
{
   CX88_CARD_ID_UNKNOWN,
   CX88_CARD_ID_PCHDTV_HD3000,
   CX88_CARD_ID_PCHDTV_HD5500,
   CX88_CARD_ID_WINTV_NOVA_T,
   CX88_CARD_ID_FUSION_5_GOLD,
   CX88_CARD_ID_CLUB3D_ZAP_TV2100,
   CX88_CARD_ID_REF_DVBT,
   CX88_CARD_ID_KWORLD_VSTREAM_XPERT,
   CX88_CARD_ID_TERRATEC_CINERGY_1400,
   CX88_CARD_ID_LEADTEK_WINFAST_DTV1000T,
   CX88_CARD_ID_WINTV_HVR1100,
   CX88_CARD_ID_LEADTEK_WINFAST_DTV2000H,
   CX88_CARD_ID_WINTV_HVR1300,
   CX88_CARD_ID_WINTV_HVR3000,
   CX88_CARD_ID_WINTV_HVR4000,
   CX88_CARD_ID_PIXELVIEW_XCAPTURE,
   CX88_CARD_ID_WINTV_HVR1250,
   CX88_CARD_ID_WINTV_HVR1800,
   CX88_CARD_ID_FUSION_7_DUAL,
   CX88_CARD_ID_WINTV_HVR1850
};

cx88_card_id get_card_id(tuner_config &conf, const char *devnode);
int cx88_open_bridge(int fd);

#endif

==> cx88-1.4.4.tar.gz: cx88-1.4.4/client/drivers/cx88_cards.h <==
/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_CARDS_H__
#define __CX88_CARDS_H__

#include "tuner_config.h"

enum cx88_card_id
{
   CX88_CARD_ID_UNKNOWN,
   CX88_CARD_ID_PCHDTV_HD3000,
   CX88_CARD_ID_PCHDTV_HD5500,
   CX88_CARD_ID_WINTV_NOVA_T,
   CX88_CARD_ID_FUSION_5_GOLD,
   CX88_CARD_ID_CLUB3D_ZAP_TV2100,
   CX88_CARD_ID_REF_DVBT,
   CX88_CARD_ID_KWORLD_VSTREAM_XPERT,
   CX88_CARD_ID_TERRATEC_CINERGY_1400,
   CX88_CARD_ID_LEADTEK_WINFAST_DTV1000T,
   CX88_CARD_ID_WINTV_HVR1100,
   CX88_CARD_ID_LEADTEK_WINFAST_DTV2000H,
   CX88_CARD_ID_WINTV_HVR1300,
   CX88_CARD_ID_WINTV_HVR3000,
   CX88_CARD_ID_WINTV_HVR4000,
   CX88_CARD_ID_PIXELVIEW_XCAPTURE,
   CX88_CARD_ID_WINTV_HVR1250,
   CX88_CARD_ID_WINTV_HVR1800,
   CX88_CARD_ID_FUSION_7_DUAL,
   CX88_CARD_ID_WINTV_HVR1850,
   CX88_CARD_ID_WINTV_PCI_FM,
   CX88_CARD_ID_HDTV_WONDER
};

cx88_card_id get_card_id(tuner_config &conf, const char *devnode);
int cx88_open_bridge(int fd);

#endif
